package mpwechat

import (
	base_ctl "SCRM/controllers"
	"SCRM/enums"
	"SCRM/service/wechat_service"
	"SCRM/utils"
	"bytes"
	"mime/multipart"
	"sync"

	"io"

	"github.com/astaxie/beego"
	"github.com/astaxie/beego/httplib"
)

func MpMaterialCtlRegistRouters() {
	beego.Router("/api/mpwechat/media/add_material", &MpMaterialAPIController{}, "Post:AddMaterial")
}

type MpMaterialAPIController struct {
	base_ctl.BaseAuthAPIController
}

type MultipartFormField struct {
	IsFile   bool
	Name     string
	FileName string
	Value    io.Reader
}

var mediaBufferPool = sync.Pool{
	New: func() interface{} {
		return bytes.NewBuffer(make([]byte, 0, 10<<20)) // 10MB
	},
}

func (c MpMaterialAPIController) AddMaterial() {

	adminUserInfo := c.GetAdminUserInfo()

	authorization, err := wechat_service.GetAuthorizationByOrgID(adminUserInfo.CurrentOrgId)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDataException, "上传失败:（"+err.Error()+"）")
		return
	}
	if authorization == nil || authorization.AuthorizerStatus != 1 {
		c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "上传失败:（公众号未授权）")
		return
	}

	file, head, err := c.GetFile("file")
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "上传失败:（"+err.Error()+"）")
		return
	}
	defer file.Close()

	var fields = []MultipartFormField{
		{
			IsFile:   true,
			Name:     "media",
			FileName: head.Filename,
			Value:    file,
		},
	}

	buffer := mediaBufferPool.Get().(*bytes.Buffer)
	buffer.Reset()
	defer mediaBufferPool.Put(buffer)

	multipartWriter := multipart.NewWriter(buffer)
	for i := 0; i < len(fields); i++ {
		if field := &fields[i]; field.IsFile {
			partWriter, err3 := multipartWriter.CreateFormFile(field.Name, field.FileName)
			if err3 != nil {
				c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "上传失败:（"+err3.Error()+"）")
				return
			}
			if _, err3 = io.Copy(partWriter, field.Value); err3 != nil {
				c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "上传失败:（"+err3.Error()+"）")
				return
			}
		} else {
			partWriter, err3 := multipartWriter.CreateFormField(field.Name)
			if err3 != nil {
				c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "上传失败:（"+err3.Error()+"）")
				return
			}
			if _, err3 = io.Copy(partWriter, field.Value); err3 != nil {
				c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "上传失败:（"+err3.Error()+"）")
				return
			}
		}
	}

	if err = multipartWriter.Close(); err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "上传失败:（"+err.Error()+"）")
		return
	}
	requestBodyBytes := buffer.Bytes()
	requestBodyType := multipartWriter.FormDataContentType()
	url := "https://api.weixin.qq.com/cgi-bin/material/add_material?type=image&access_token=" + authorization.AuthorizerAccessToken
	res := httplib.Post(url)
	res.Header("Content-Type", requestBodyType)
	res.Body(requestBodyBytes)
	response := make(map[string]interface{}, 0)
	res.ToJSON(&response)
	utils.InfoLog("%v", response)

	returnData := make(map[string]interface{}, 0)
	returnData["ok"] = "msg"
	c.ServeSuccessJSON(returnData)
	return
}
